@@ -1,5 +1,5 @@
 /*
-  Copyright 2022 Northern.tech AS
+  Copyright 2024 Northern.tech AS
 
   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
 
@@ -26,7 +26,7 @@
 
 #include <openssl/bn.h>                                    /* BN_* */
 #include <openssl/err.h>                                   /* ERR_get_error */
-#include <libcrypto-compat.h>
+#include <openssl/rsa.h>
 
 #include <communication.h>
 #include <net.h>
