@@ -1,5 +1,5 @@
 /*
-  Copyright 2022 Northern.tech AS
+  Copyright 2024 Northern.tech AS
 
   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
 
@@ -177,7 +177,7 @@ Class *ClassTableMatch(const ClassTable *table, const char *regex)
     ClassTableIterator *it = ClassTableIteratorNew(table, NULL, true, true);
     Class *cls = NULL;
 
-    pcre *pattern = CompileRegex(regex);
+    Regex *pattern = CompileRegex(regex);
     if (pattern == NULL)
     {
         // TODO: perhaps pcre has can give more info on this error?
@@ -205,7 +205,7 @@ Class *ClassTableMatch(const ClassTable *table, const char *regex)
         }
     }
 
-    pcre_free(pattern);
+    RegexDestroy(pattern);
 
     ClassTableIteratorDestroy(it);
     return cls;
